# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.1
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ngl
else:
    import _ngl

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ngl.delete_SwigPyIterator

    def value(self):
        return _ngl.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _ngl.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _ngl.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _ngl.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _ngl.SwigPyIterator_equal(self, x)

    def copy(self):
        return _ngl.SwigPyIterator_copy(self)

    def next(self):
        return _ngl.SwigPyIterator_next(self)

    def __next__(self):
        return _ngl.SwigPyIterator___next__(self)

    def previous(self):
        return _ngl.SwigPyIterator_previous(self)

    def advance(self, n):
        return _ngl.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _ngl.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _ngl.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _ngl.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _ngl.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _ngl.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _ngl.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ngl:
_ngl.SwigPyIterator_swigregister(SwigPyIterator)

class nglGraph(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, Xin, rows, cols, graph, maxN, beta, edgeIndices, connect=False):
        _ngl.nglGraph_swiginit(self, _ngl.new_nglGraph(Xin, rows, cols, graph, maxN, beta, edgeIndices, connect))

    def dimension(self):
        return _ngl.nglGraph_dimension(self)

    def size(self):
        return _ngl.nglGraph_size(self)

    def max(self, dim):
        return _ngl.nglGraph_max(self, dim)

    def min(self, dim):
        return _ngl.nglGraph_min(self, dim)

    def range(self, dim):
        return _ngl.nglGraph_range(self, dim)

    def get_x(self, *args):
        return _ngl.nglGraph_get_x(self, *args)

    def full_graph(self):
        return _ngl.nglGraph_full_graph(self)

    def get_neighbors(self, index):
        return _ngl.nglGraph_get_neighbors(self, index)
    __swig_destroy__ = _ngl.delete_nglGraph

# Register nglGraph in _ngl:
_ngl.nglGraph_swigregister(nglGraph)

class vectorDouble(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _ngl.vectorDouble_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _ngl.vectorDouble___nonzero__(self)

    def __bool__(self):
        return _ngl.vectorDouble___bool__(self)

    def __len__(self):
        return _ngl.vectorDouble___len__(self)

    def __getslice__(self, i, j):
        return _ngl.vectorDouble___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _ngl.vectorDouble___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _ngl.vectorDouble___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _ngl.vectorDouble___delitem__(self, *args)

    def __getitem__(self, *args):
        return _ngl.vectorDouble___getitem__(self, *args)

    def __setitem__(self, *args):
        return _ngl.vectorDouble___setitem__(self, *args)

    def pop(self):
        return _ngl.vectorDouble_pop(self)

    def append(self, x):
        return _ngl.vectorDouble_append(self, x)

    def empty(self):
        return _ngl.vectorDouble_empty(self)

    def size(self):
        return _ngl.vectorDouble_size(self)

    def swap(self, v):
        return _ngl.vectorDouble_swap(self, v)

    def begin(self):
        return _ngl.vectorDouble_begin(self)

    def end(self):
        return _ngl.vectorDouble_end(self)

    def rbegin(self):
        return _ngl.vectorDouble_rbegin(self)

    def rend(self):
        return _ngl.vectorDouble_rend(self)

    def clear(self):
        return _ngl.vectorDouble_clear(self)

    def get_allocator(self):
        return _ngl.vectorDouble_get_allocator(self)

    def pop_back(self):
        return _ngl.vectorDouble_pop_back(self)

    def erase(self, *args):
        return _ngl.vectorDouble_erase(self, *args)

    def __init__(self, *args):
        _ngl.vectorDouble_swiginit(self, _ngl.new_vectorDouble(*args))

    def push_back(self, x):
        return _ngl.vectorDouble_push_back(self, x)

    def front(self):
        return _ngl.vectorDouble_front(self)

    def back(self):
        return _ngl.vectorDouble_back(self)

    def assign(self, n, x):
        return _ngl.vectorDouble_assign(self, n, x)

    def resize(self, *args):
        return _ngl.vectorDouble_resize(self, *args)

    def insert(self, *args):
        return _ngl.vectorDouble_insert(self, *args)

    def reserve(self, n):
        return _ngl.vectorDouble_reserve(self, n)

    def capacity(self):
        return _ngl.vectorDouble_capacity(self)
    __swig_destroy__ = _ngl.delete_vectorDouble

# Register vectorDouble in _ngl:
_ngl.vectorDouble_swigregister(vectorDouble)

class vectorInt(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _ngl.vectorInt_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _ngl.vectorInt___nonzero__(self)

    def __bool__(self):
        return _ngl.vectorInt___bool__(self)

    def __len__(self):
        return _ngl.vectorInt___len__(self)

    def __getslice__(self, i, j):
        return _ngl.vectorInt___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _ngl.vectorInt___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _ngl.vectorInt___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _ngl.vectorInt___delitem__(self, *args)

    def __getitem__(self, *args):
        return _ngl.vectorInt___getitem__(self, *args)

    def __setitem__(self, *args):
        return _ngl.vectorInt___setitem__(self, *args)

    def pop(self):
        return _ngl.vectorInt_pop(self)

    def append(self, x):
        return _ngl.vectorInt_append(self, x)

    def empty(self):
        return _ngl.vectorInt_empty(self)

    def size(self):
        return _ngl.vectorInt_size(self)

    def swap(self, v):
        return _ngl.vectorInt_swap(self, v)

    def begin(self):
        return _ngl.vectorInt_begin(self)

    def end(self):
        return _ngl.vectorInt_end(self)

    def rbegin(self):
        return _ngl.vectorInt_rbegin(self)

    def rend(self):
        return _ngl.vectorInt_rend(self)

    def clear(self):
        return _ngl.vectorInt_clear(self)

    def get_allocator(self):
        return _ngl.vectorInt_get_allocator(self)

    def pop_back(self):
        return _ngl.vectorInt_pop_back(self)

    def erase(self, *args):
        return _ngl.vectorInt_erase(self, *args)

    def __init__(self, *args):
        _ngl.vectorInt_swiginit(self, _ngl.new_vectorInt(*args))

    def push_back(self, x):
        return _ngl.vectorInt_push_back(self, x)

    def front(self):
        return _ngl.vectorInt_front(self)

    def back(self):
        return _ngl.vectorInt_back(self)

    def assign(self, n, x):
        return _ngl.vectorInt_assign(self, n, x)

    def resize(self, *args):
        return _ngl.vectorInt_resize(self, *args)

    def insert(self, *args):
        return _ngl.vectorInt_insert(self, *args)

    def reserve(self, n):
        return _ngl.vectorInt_reserve(self, n)

    def capacity(self):
        return _ngl.vectorInt_capacity(self)
    __swig_destroy__ = _ngl.delete_vectorInt

# Register vectorInt in _ngl:
_ngl.vectorInt_swigregister(vectorInt)

class setInt(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _ngl.setInt_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _ngl.setInt___nonzero__(self)

    def __bool__(self):
        return _ngl.setInt___bool__(self)

    def __len__(self):
        return _ngl.setInt___len__(self)

    def append(self, x):
        return _ngl.setInt_append(self, x)

    def __contains__(self, x):
        return _ngl.setInt___contains__(self, x)

    def __getitem__(self, i):
        return _ngl.setInt___getitem__(self, i)

    def add(self, x):
        return _ngl.setInt_add(self, x)

    def discard(self, x):
        return _ngl.setInt_discard(self, x)

    def __init__(self, *args):
        _ngl.setInt_swiginit(self, _ngl.new_setInt(*args))

    def empty(self):
        return _ngl.setInt_empty(self)

    def size(self):
        return _ngl.setInt_size(self)

    def clear(self):
        return _ngl.setInt_clear(self)

    def swap(self, v):
        return _ngl.setInt_swap(self, v)

    def count(self, x):
        return _ngl.setInt_count(self, x)

    def begin(self):
        return _ngl.setInt_begin(self)

    def end(self):
        return _ngl.setInt_end(self)

    def rbegin(self):
        return _ngl.setInt_rbegin(self)

    def rend(self):
        return _ngl.setInt_rend(self)

    def erase(self, *args):
        return _ngl.setInt_erase(self, *args)

    def find(self, x):
        return _ngl.setInt_find(self, x)

    def lower_bound(self, x):
        return _ngl.setInt_lower_bound(self, x)

    def upper_bound(self, x):
        return _ngl.setInt_upper_bound(self, x)

    def equal_range(self, x):
        return _ngl.setInt_equal_range(self, x)

    def insert(self, __x):
        return _ngl.setInt_insert(self, __x)
    __swig_destroy__ = _ngl.delete_setInt

# Register setInt in _ngl:
_ngl.setInt_swigregister(setInt)

class mapIntSet(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _ngl.mapIntSet_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _ngl.mapIntSet___nonzero__(self)

    def __bool__(self):
        return _ngl.mapIntSet___bool__(self)

    def __len__(self):
        return _ngl.mapIntSet___len__(self)
    def __iter__(self):
        return self.key_iterator()
    def iterkeys(self):
        return self.key_iterator()
    def itervalues(self):
        return self.value_iterator()
    def iteritems(self):
        return self.iterator()

    def __getitem__(self, key):
        return _ngl.mapIntSet___getitem__(self, key)

    def __delitem__(self, key):
        return _ngl.mapIntSet___delitem__(self, key)

    def has_key(self, key):
        return _ngl.mapIntSet_has_key(self, key)

    def keys(self):
        return _ngl.mapIntSet_keys(self)

    def values(self):
        return _ngl.mapIntSet_values(self)

    def items(self):
        return _ngl.mapIntSet_items(self)

    def __contains__(self, key):
        return _ngl.mapIntSet___contains__(self, key)

    def key_iterator(self):
        return _ngl.mapIntSet_key_iterator(self)

    def value_iterator(self):
        return _ngl.mapIntSet_value_iterator(self)

    def __setitem__(self, *args):
        return _ngl.mapIntSet___setitem__(self, *args)

    def asdict(self):
        return _ngl.mapIntSet_asdict(self)

    def __init__(self, *args):
        _ngl.mapIntSet_swiginit(self, _ngl.new_mapIntSet(*args))

    def empty(self):
        return _ngl.mapIntSet_empty(self)

    def size(self):
        return _ngl.mapIntSet_size(self)

    def swap(self, v):
        return _ngl.mapIntSet_swap(self, v)

    def begin(self):
        return _ngl.mapIntSet_begin(self)

    def end(self):
        return _ngl.mapIntSet_end(self)

    def rbegin(self):
        return _ngl.mapIntSet_rbegin(self)

    def rend(self):
        return _ngl.mapIntSet_rend(self)

    def clear(self):
        return _ngl.mapIntSet_clear(self)

    def get_allocator(self):
        return _ngl.mapIntSet_get_allocator(self)

    def count(self, x):
        return _ngl.mapIntSet_count(self, x)

    def erase(self, *args):
        return _ngl.mapIntSet_erase(self, *args)

    def find(self, x):
        return _ngl.mapIntSet_find(self, x)

    def lower_bound(self, x):
        return _ngl.mapIntSet_lower_bound(self, x)

    def upper_bound(self, x):
        return _ngl.mapIntSet_upper_bound(self, x)
    __swig_destroy__ = _ngl.delete_mapIntSet

# Register mapIntSet in _ngl:
_ngl.mapIntSet_swigregister(mapIntSet)






""" This module will test the functionality of nglpy.utils
"""
import unittest
import warnings

import nglpy


class TestUtils(unittest.TestCase):
    """Class for testing the utils"""

    def test_consume_extra_args_with_exception(self):
        """Tests the consume_extra_args function raises an exception."""
        unused = {"extra": "word"}
        msg = "Warning: the current version of nglpy does not accept"
        with self.assertRaises(NotImplementedError) as context:
            nglpy.utils.consume_extra_args(fail_on_missing=True, **unused)
            self.assertTrue(msg in context.exception)

    def test_consume_extra_args(self):
        """Tests the consume_extra_args function raises a warning."""
        unused = {"extra": "word"}
        msg = "Warning: the current version of nglpy does not accept"
        with warnings.catch_warnings(record=True) as w:
            warnings.simplefilter("always")
            nglpy.utils.consume_extra_args(fail_on_missing=False, **unused)

            self.assertEqual(len(w), 1)
            self.assertTrue(issubclass(w[-1].category, UserWarning))
            self.assertTrue(msg in str(w[-1].message))


if __name__ == "__main__":
    unittest.main()



"""
      Setup script for nglpy, a wrapper library for the C++
      implementataion of the neighborhood graph library (NGL).
"""

import sys

from setuptools import Extension, setup

requirements = open("requirements.txt").read().strip().split("\n")
extra_compile_args = []  # type: ignore
extra_link_args = []  # type: ignore
if sys.platform == "darwin":
    extra_compile_args = ["-stdlib=libc++"]
    extra_link_args = ["-stdlib=libc++"]


FILES = ["ngl_wrap.cpp", "GraphStructure.cpp", "UnionFind.cpp"]


def long_description():
    """Reads the README.rst file and extracts the portion tagged between
    specific LONG_DESCRIPTION comment lines.
    """
    description = ""
    recording = False
    with open("README.rst") as f:
        for line in f:
            if "END_LONG_DESCRIPTION" in line:
                return description
            elif "LONG_DESCRIPTION" in line:
                recording = True
                continue

            if recording:
                description += line


# Consult here: https://packaging.python.org/tutorials/distributing-packages/
setup(
    name="nglpy",
    packages=["nglpy"],
    description="A wrapper library for exposing the C++ neighborhood "
    + "graph library (NGL) for computing empty region graphs to "
    + "python",
    long_description=long_description(),
    test_suite="nglpy.tests",
    install_requires=requirements,
    python_requires=">=2.7, <4",
    ext_modules=[
        Extension(
            "nglpy._ngl",
            FILES,
            extra_compile_args=[
                "-std=c++11",
                "-O3",
                *extra_compile_args,
            ],
            extra_link_args=extra_link_args,
        )
    ],
)



"""
    Utility library for NGLPy
"""

import warnings


def consume_extra_args(fail_on_missing=False, **kwargs):
    """
    Supports forward compatibility.

    This helper function will take all of the extra arguments not currently
    used by a calling function/environment, and print a warning to standard
    error letting them know they are using an unsupported feature passed into a
    function.

    Parameters
    ----------
    fail_on_missing : bool
      A flag specifying whether missing arguments should throw a warning
      (False) or an exception (True)
    kwargs : dict
      A dictionary of keyword arguments not used by an existing interface.

    Returns
    -------
    None

    """
    for kw in kwargs:
        msg = f"Warning: the current version of nglpy does not accept {kw}. "
        if fail_on_missing:
            raise NotImplementedError(msg)
        else:
            msg += "It will be ignored."
            warnings.warn(msg, UserWarning, stacklevel=3)
